==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/NpmConfigOptions.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Options to configure the local NPM config.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.886Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.NpmConfigOptions")
@software.amazon.jsii.Jsii.Proxy(NpmConfigOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NpmConfigOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) URL of the registry mirror to use.
     * <p>
     * You can change this or add scoped registries using the addRegistry method
     * <p>
     * Default: - use npmjs default registry
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRegistry() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NpmConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NpmConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NpmConfigOptions> {
        java.lang.String registry;

        /**
         * Sets the value of {@link NpmConfigOptions#getRegistry}
         * @param registry URL of the registry mirror to use.
         *                 You can change this or add scoped registries using the addRegistry method
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder registry(java.lang.String registry) {
            this.registry = registry;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NpmConfigOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NpmConfigOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NpmConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NpmConfigOptions {
        private final java.lang.String registry;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.registry = software.amazon.jsii.Kernel.get(this, "registry", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.registry = builder.registry;
        }

        @Override
        public final java.lang.String getRegistry() {
            return this.registry;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRegistry() != null) {
                data.set("registry", om.valueToTree(this.getRegistry()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.NpmConfigOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NpmConfigOptions.Jsii$Proxy that = (NpmConfigOptions.Jsii$Proxy) o;

            return this.registry != null ? this.registry.equals(that.registry) : that.registry == null;
        }

        @Override
        public final int hashCode() {
            int result = this.registry != null ? this.registry.hashCode() : 0;
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/NpmConfigOptions.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Options to configure the local NPM config.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.543Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.NpmConfigOptions")
@software.amazon.jsii.Jsii.Proxy(NpmConfigOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NpmConfigOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Omits empty objects and arrays.
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getOmitEmpty() {
        return null;
    }

    /**
     * (experimental) URL of the registry mirror to use.
     * <p>
     * You can change this or add scoped registries using the addRegistry method
     * <p>
     * Default: - use npmjs default registry
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getRegistry() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NpmConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NpmConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NpmConfigOptions> {
        java.lang.Boolean omitEmpty;
        java.lang.String registry;

        /**
         * Sets the value of {@link NpmConfigOptions#getOmitEmpty}
         * @param omitEmpty Omits empty objects and arrays.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder omitEmpty(java.lang.Boolean omitEmpty) {
            this.omitEmpty = omitEmpty;
            return this;
        }

        /**
         * Sets the value of {@link NpmConfigOptions#getRegistry}
         * @param registry URL of the registry mirror to use.
         *                 You can change this or add scoped registries using the addRegistry method
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder registry(java.lang.String registry) {
            this.registry = registry;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NpmConfigOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NpmConfigOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NpmConfigOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NpmConfigOptions {
        private final java.lang.Boolean omitEmpty;
        private final java.lang.String registry;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.omitEmpty = software.amazon.jsii.Kernel.get(this, "omitEmpty", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.registry = software.amazon.jsii.Kernel.get(this, "registry", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.omitEmpty = builder.omitEmpty;
            this.registry = builder.registry;
        }

        @Override
        public final java.lang.Boolean getOmitEmpty() {
            return this.omitEmpty;
        }

        @Override
        public final java.lang.String getRegistry() {
            return this.registry;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getOmitEmpty() != null) {
                data.set("omitEmpty", om.valueToTree(this.getOmitEmpty()));
            }
            if (this.getRegistry() != null) {
                data.set("registry", om.valueToTree(this.getRegistry()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.NpmConfigOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NpmConfigOptions.Jsii$Proxy that = (NpmConfigOptions.Jsii$Proxy) o;

            if (this.omitEmpty != null ? !this.omitEmpty.equals(that.omitEmpty) : that.omitEmpty != null) return false;
            return this.registry != null ? this.registry.equals(that.registry) : that.registry == null;
        }

        @Override
        public final int hashCode() {
            int result = this.omitEmpty != null ? this.omitEmpty.hashCode() : 0;
            result = 31 * result + (this.registry != null ? this.registry.hashCode() : 0);
            return result;
        }
    }
}
